#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['nome']

package_data = \
{'': ['*']}

setup(name='nome',
      version='0.0.1',
      description='A Python CLI to check if a package name is available in PyPI or npm.',
      author='João Palmeiro',
      author_email='joaommpalmeiro@gmail.com',
      url='https://github.com/joaopalmeiro/nome',
      packages=packages,
      package_data=package_data,
      python_requires='>=3.6,<4',
     )
